<?php

require_once('api/Simpla.php');
require_once(__DIR__ . '/include.php');

class RBSPayment extends Simpla
{

    public $getaway_url;
    public $module_version = '1.0.1';

    public function checkout_form($order_id, $button_text = null)
    {
        if($this->request->method('post') && $this->request->post('go'))
        {
            $this->redirect($order_id);
        }
        else
        {
            $button =	"<form method=POST>".
                "<input name=go type=submit class=checkout_button
						 value='Перейти к оплате &#8594;'>".
                "</form>";
            return $button;
        }
    }

    public function redirect($order_id)
    {
        $order = $this->orders->get_order((int)$order_id);

        $payment_method = $this->payment->get_payment_method($order->payment_method_id);
        $payment_settings = $this->payment->get_payment_settings($payment_method->id);

        $price = $this->money->convert($order->total_price, $payment_method->currency_id, false);
        $return_url = $this->config->root_url.'/payment/RBSPayment/callback.php?o='.$order->id;

        if ($payment_settings['test_mode'] == 1) {
            $action_adr = RBS_TEST_URL;
        } else {
            $action_adr = RBS_PROD_URL;
        }

        if ($payment_settings['stage_mode'] == 'two-stage') {
            $action_adr .= 'registerPreAuth.do';
        } else {
            $action_adr .= 'register.do';
        }

        $args = array(
            'userName' => $payment_settings['merchant'],
            'password' => $payment_settings['password'],
            'orderNumber' => $order->id . '_' .time(),
            'amount' => $price * 100,
            'returnUrl' => $return_url,
            'jsonParams' => json_encode(
                array(
                    'CMS: ' => 'SimplaCMS version: '. $this->config->version,
                    'Module-Version: ' => $this->module_version
                )
            ),
        );

        // ------------------------------------------------------------------------------------------------
        //ob
        if ($payment_settings['send_order'] == 1) {

            $args['taxSystem'] = $payment_settings['tax_system'];

            $order_items = $this->orders->get_purchases(array('order_id' => $order->id));

            $order_date_created = strtotime($order->date);
            $order_billing_email = $order->email;
            $order_billing_phone = $order->phone;

            $items = array();
            $itemsCnt = 1;


            /* Заполнение массива данных корзины */
            foreach ($order_items as $value) {
                $item = array();

                $product_price = round(($value->price) * 100);

                $item['positionId'] = $itemsCnt++;
                $item['name'] = $value->product_name;

                $item['quantity'] = array(
                    'value' => $value->amount,
                    'measure' => "шт"
                );
                $item['itemAmount'] = $product_price * $value->amount;
                $item['itemCode'] = $value->product_id;
                $item['tax'] = array(
                    'taxType' => 0 // <--------------------
                );
                $item['itemPrice'] = $product_price;

                // FFD 1.05 added
                if ($payment_settings['ffd_version'] == 'v105') {

                    $attributes = array();
                    $attributes[] = array(
                        "name" => "paymentMethod",
                        "value" => $payment_settings['ffd_paymentMethodType']
                    );
                    $attributes[] = array(
                        "name" => "paymentObject",
                        "value" => $payment_settings['ffd_paymentObjectType']
                    );

                    $item['itemAttributes']['attributes'] = $attributes;
                }

                $items[] = $item;
            }

            // DELIVERY POSITION
            if ($order->delivery_price > 0) {
                $itemShipment['positionId'] = $itemsCnt;
                $itemShipment['name'] = 'Доставка';
                $itemShipment['quantity'] = array(
                    'value' => 1,
                    'measure' => "шт"
                );
                $itemShipment['itemAmount'] = $itemShipment['itemPrice'] = $order->delivery_price * 100;
                $itemShipment['itemCode'] = 'Delivery';
                $itemShipment['tax'] = array(
                    'taxType' => 0 // <--------------------
                );

                // FFD 1.05 added
                if ($payment_settings['ffd_version'] == 'v105') {
                    $attributes = array();
                    $attributes[] = array(
                        "name" => "paymentMethod",
                        "value" => 4
                    );
                    $attributes[] = array(
                        "name" => "paymentObject",
                        "value" => 4
                    );

                    $itemShipment['itemAttributes']['attributes'] = $attributes;

                }

                $items[] = $itemShipment;
            }


            /* Создание и заполнение массива данных заказа для фискализации */
            $order_bundle = array(
                'orderCreationDate' => $order_date_created,
                'customerDetails' => array(
                    'email' => $order_billing_email
                ),
                'cartItems' => array('items' => $items)
            );

            /* Заполнение массива данных для запроса c фискализацией */
            $args['orderBundle'] = json_encode($order_bundle);
        }
        // ------------------------------------------------------------------------------------------------

        $response = $this->gateway($args, $action_adr);
        $response = json_decode($response, true);

        if ($response['errorCode'] != 0)
        {
            print($response['errorMessage']);
        }
        else
        {
            print "REDIRECT";
            header('Location: '.$response['formUrl']);
        }
        exit;
    }


    public function gateway($args, $action_adr)
    {

        $rbsCurl = curl_init();
        curl_setopt_array($rbsCurl, array(
            CURLOPT_HTTPHEADER => array(
                'CMS: SimplaCMS version: ' . $this->config->version,
                'Module-Version: ' . $this->module_version,
            ),
            CURLOPT_URL => $action_adr,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_SSL_VERIFYPEER => false,
            CURLOPT_POST => true,
            CURLOPT_POSTFIELDS => http_build_query($args, '', '&')
        ));

        $response = curl_exec($rbsCurl);
        curl_close($rbsCurl);
        return $response; // Возвращаем ответ

    }
}